@@ -14,24 +14,36 @@ if [ ! -f "/sys/devices/system/cpu/cpu0/cpufreq/scaling_governor" ]; then
 	echo "This probably means that you have disabled processor scheduling features in your BIOS. See README.md (or GitHub issue #44) for more information."
 	echo "This means GameMode's CPU governor control feature will not work (other features will still work)."
 
-	# Allow to continue the install, as gamemode has other useful features
-	read -p "Would you like to continue anyway [Y/N]? " -r
-	[[ $REPLY =~ ^[Yy]$ ]]
+	if [ "$TRAVIS" != "true" ]; then
+		# Allow to continue the install, as gamemode has other useful features
+		read -p "Would you like to continue anyway [Y/N]? " -r
+		[[ $REPLY =~ ^[Yy]$ ]]
+	fi
 fi
 
+# accept a prefix value as: prefix=/path ./bootstrap.sh
+: ${prefix:=/usr}
+
 # Echo the rest so it's obvious
 set -x
-meson --prefix=/usr build -Dwith-systemd-user-unit-dir=/etc/systemd/user
+meson --prefix=$prefix build --buildtype debugoptimized -Dwith-systemd-user-unit-dir=/etc/systemd/user "$@"
 cd build
 ninja
 
 # Verify user wants to install
 set +x
-read -p "Install to /usr? [Yy] " -r
-[[ $REPLY =~ ^[Yy]$ ]]
+if [ "$TRAVIS" != "true" ]; then
+	read -p "Install to $prefix? [y/N] " -r
+	[[ $REPLY =~ ^[Yy]$ ]]
+fi
 set -x
 
 sudo ninja install
 
+# Restart polkit so we don't get pop-ups whenever we pkexec
+if systemctl list-unit-files |grep -q polkit.service; then
+    sudo systemctl try-restart polkit
+fi
+
 # Reload systemd configuration so that it picks up the new service.
 systemctl --user daemon-reload
